@@ -114,8 +114,6 @@ class Module:
 
         # Gtk themes -- Only shows themes that have a gtk-3.* variation
         for (name, path) in walk_directories(THEME_FOLDERS, self.filter_func_gtk_dir, return_directories=True):
-            if name.lower() in THEMES_BLACKLIST:
-                continue
             for theme in self.gtk_themes:
                 if name == theme[0]:
                     if path == THEME_FOLDERS[0]:
@@ -142,12 +140,12 @@ class Module:
         walked = walk_directories(ICON_FOLDERS, lambda d: os.path.isdir(d), return_directories=True)
         valid = []
         for directory in walked:
-            if directory[0].lower() in THEMES_BLACKLIST:
-                continue
             path = os.path.join(directory[1], directory[0], "index.theme")
             if os.path.exists(path):
                 try:
                     for line in list(open(path)):
+                        if line.startswith("Hidden=true"):
+                            break
                         if line.startswith("Directories="):
                             valid.append(directory)
                             break
@@ -160,8 +158,6 @@ class Module:
 
         # Cursor themes
         for (name, path) in walk_directories(ICON_FOLDERS, lambda d: os.path.isdir(d) and os.path.exists(os.path.join(d, "cursors")), return_directories=True):
-            if name.lower() in THEMES_BLACKLIST:
-                continue
             for theme in self.cursor_themes:
                 if name == theme[0]:
                     if path == ICON_FOLDERS[0]:
